<template>
    <div class="_wrapper mt-4">
        <div class="_register_form_side w-tab pa-4">
            <h1 class="text-left full">Create Account</h1>
            <v-form  class="_main_form" ref="form" @submit.prevent="sendOTP">
                <div class="mobile_validatation">
                  <div class="input-field relative">
                      <v-text-field
                          autofocus
                          name="mobile"
                          label="Mobile"
                          :mask="mobileMask"
                          v-model="auth.mobile"
                          :rules="mobileRules"
                          type="tel"
                          persistent-hint
                          hint="Code will be sent on given mobile number"
                      ></v-text-field>

                      <v-btn 
                        :loading="sending" 
                        v-if="mRegister" 
                        small 
                        flat 
                        class="_sendcode" 
                        @click="sendOTP"
                    >{{ send_otp }}</v-btn>

                      <v-btn 
                        :loading="sending" 
                        v-else 
                        large 
                        class="__sendcode full" 
                        color="secondary" 
                        type="submit"
                     >
                        {{ send_otp }}
                    </v-btn>

                  </div>
                </div>
                <div class="register_form" v-if="mRegister">
                  <div class="input-field">
                    <v-text-field
                    name="code"
                    label="Code"
                    autofocus
                    v-model="auth.code"
                    hint="Code will be sent on given mobile number"
                    :rules="validateRules"
                    :mask="otp_format"
                    type="tel"
                    ></v-text-field>
                  </div>
                  <div class="input-field">
                    <v-text-field
                    name="company"
                    label="Company"
                    v-model="auth.company"
                    ></v-text-field>
                  </div>
                  <div class="input-field">
                    <v-text-field
                    name="name"
                    label="Full Name"
                    v-model="auth.name"
                    :rules="validateRules"
                    ></v-text-field>
                  </div>
                  <div class="input-field">
                    <v-text-field
                    name="email"
                    label="Email"
                    v-model="auth.email"
                    :rules="emailRules"
                    type="email"
                    ></v-text-field>
                  </div>
                  <div class="input-field">
                    <v-text-field
                    name="password"
                    label="Password"
                    v-model="auth.pass"
                    :rules="passwordRule"
                    type="password"
                    persistent-hint
                    hint="Min. 6 character"
                    ></v-text-field>
                  </div>
                  <div class="input-field _submit_section display-flex align-center">
                    <div class="check_box m0 flex align-center">
                      <v-checkbox
                      label="I accept "
                      class="terms"
                      :rules="validateRules"
                      name="terms"
                      ></v-checkbox>
                      <nuxt-link to="/page/terms" class="_tnc">Terms & Conditions</nuxt-link>
                    </div>
                    <v-btn
                    large
                    :loading="loading"
                    @click="register"
                    color="secondary">
                    Sign Up
                  </v-btn>
                </div>
                </div>
                <div class="align-center flex justify-center">
                    Already Register?
                    <strong class="pointer ml-1">
                        <nuxt-link to="/account/login">
                            Log In
                        </nuxt-link>
                    </strong>
                </div>
            </v-form>
        </div>
    </div>
</template>
<script>
import axios from 'axios';
export default {
    layout: 'auth',
    data () {
        return {
            send_otp: 'Get Started',
            sending: false,
            otp_format: '###-###',
            mobileMask: 'phone',
            validateRules: [],
            mRegister: false,
            loading: false,
            mobileRules: [
                v => !!v && v.length >= 10 || 'Mobile must be 10 digit number'
            ],
            validateRules: [
                v => !!v || 'This field is required'
            ],
            passwordRule: [
               v => !!v && v.length >= 6 || 'Minimum 6 characters require'
            ],
            emailRules: [
                v => !!v || 'E-mail is required',
                v => /.+@.+/.test(v) || 'E-mail must be valid'
            ],
            auth: []
        }
    },
    methods: {
        register: function () {
            if (this.$refs.form.validate()) {
                this.loading = true;
                var form_data = new FormData();
                form_data.append('name', this.auth.name);
                form_data.append('email', this.auth.email);
                form_data.append('mobile', this.auth.mobile);
                form_data.append('company', this.auth.company);
                form_data.append('code', this.auth.code);
                form_data.append('password', this.auth.pass);
                form_data.append('identifier', 'register');
                axios.post(this.$store.state.api_domain + '?comp=process&action=customerRegister', form_data, {withCredentials: true})
                .then((res) => {

                    this.loading = false;

                    if (res.data.status == 'success') {
                        if (this.$route.query.back) {
                            this.$router.push({
                                path: '/' + this.$route.query.back,
                                query: {
                                    secure: 'true'
                                }
                            });
                        } else {
                            this.$router.push('/');
                            this.$store.commit('showSnackBar', 'Account created successfully');
                        }
                    }

                    if (res.data.status == 'error') {
                        alert(res.data.message);
                    }
                });
            } else {
            }
        }
        ,
        sendOTP: function () {
            if (!this.auth.mobile) {
                alert('Please add mobile number to send code');
                // return false;
            }

            if (this.auth.mobile) {
                if (this.auth.mobile.length < 10) {
                    alert('Mobile number should be of 10 digits');
                } else {
                    this.sending = true;
                    var form_data = new FormData();
                    form_data.append('mobile', this.auth.mobile);
                    form_data.append('identifier', 'register');
                    axios.post(this.$store.state.api_domain + '?comp=process&action=sendOTP', form_data, {withCredentials: true})
                    .then((res) => {
                        
                        this.sending = false;
                        
                        if (res.data.status == 'success') {

                            this.mRegister = true;
                            this.send_otp = 'Code Sent!';
                            setTimeout(() => {
                                this.send_otp = 'Get Started';
                            }, 3000);

                        }

                        alert(res.data.message);
                    }).catch((e) => {
                      this.send_otp = 'Failed!';
                      this.sending = false;
                      var t = this;
                      setTimeout(function () {
                          t.send_otp = 'Get Started';
                      }, 3000);
                      alert('We could not send code');
                    });
                }
            }

            return true;
        }
    },
    head() {
        return {
            title: 'Customer Registration | Balingwiredirect.com',
            meta: [
                {hid: 'description', name: 'description', content: 'create a new account with balingwiredirect'},
                {hid: 'keywords', name: 'keywords', content: 'register'}
            ]
        }
    }
}
</script>
